
/* Chrysalide - Outil d'analyse de fichiers binaires
 * editem.c - gestion des différents éléments réactifs de l'éditeurs
 *
 * Copyright (C) 2010-2017 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#include "editem.h"


#include "editem-int.h"



/* Initialise la classe des éléments réactifs de l'éditeur. */
static void g_editor_item_class_init(GEditorItemClass *);

/* Initialise une instance d'élément réactif pour l'éditeur. */
static void g_editor_item_init(GEditorItem *);


/* Indique le type défini pour un élément réactif d'éditeur. */
G_DEFINE_TYPE(GEditorItem, g_editor_item, G_TYPE_OBJECT);


/******************************************************************************
*                                                                             *
*  Paramètres  : klass = classe à initialiser.                                *
*                                                                             *
*  Description : Initialise la classe des éléments réactifs de l'éditeur.     *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_editor_item_class_init(GEditorItemClass *klass)
{

}


/******************************************************************************
*                                                                             *
*  Paramètres  : item = instance à initialiser.                               *
*                                                                             *
*  Description : Initialise une instance d'élément réactif pour l'éditeur.    *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

static void g_editor_item_init(GEditorItem *item)
{
    DL_LIST_ITEM_INIT(&item->link);

}


/******************************************************************************
*                                                                             *
*  Paramètres  : item = instance à consulter.                                 *
*                                                                             *
*  Description : Fournit l'adresse de l'espace de référencement global.       *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

GObject *g_editor_item_get_global_ref(const GEditorItem *item)
{
    return item->ref;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : item = instance à consulter.                                 *
*                                                                             *
*  Description : Fournit le nom humain attribué à l'élément réactif.          *
*                                                                             *
*  Retour      : Désignation (courte) de l'élément de l'éditeur.              *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

const char *g_editor_item_get_name(const GEditorItem *item)
{
    return item->name;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : item = instance à consulter.                                 *
*                                                                             *
*  Description : Fournit le composant GTK associé à l'élément réactif.        *
*                                                                             *
*  Retour      : Instance de composant graphique chargé.                      *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

GtkWidget *g_editor_item_get_widget(const GEditorItem *item)
{
    return item->widget;

}


/******************************************************************************
*                                                                             *
*  Paramètres  : bar   = instance à actualiser.                               *
*                panel = composant d'affichage concerné par l'opération.      *
*                                                                             *
*  Description : Réagit à un changement de focus des panneaux d'affichage.    *
*                                                                             *
*  Retour      : -                                                            *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

void notify_focus_change_for_editor_item(GEditorItem *item, GLoadedPanel *panel)
{
    GEditorItemClass *klass;                /* Classe correspondante       */

    klass = G_EDITOR_ITEM_GET_CLASS(item);

    if (klass->notify_focus != NULL)
        klass->notify_focus(item, panel);

}
